Attribute VB_Name = "I7565H1H2_Lib"
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'                       I-7565-H1/H2 VB Library v1.09
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
Option Explicit

Public Err_String As String


'--------------------------------------------------
' Win32 API
'--------------------------------------------------
Public Declare Sub Sleep Lib "kernel32" (ByVal dwMilliseconds As Long)


'--------------------------------------------------
' Common Return Code
'--------------------------------------------------
Global Const No_Err = 0                     'No Error
Global Const DEV_ModName_Err = 1            'The Module Name Error
Global Const DEV_ModNotExist_Err = 2        'The Module doesn't exist in this Port
Global Const DEV_PortNotExist_Err = 3       'The Port doesn't Exist
Global Const DEV_PortInUse_Err = 4          'The Port is in Used
Global Const DEV_PortNotOpen_Err = 5        'The Port doesn't Open
Global Const CAN_ConfigFail_Err = 6         'CAN Hardware Init Fail
Global Const CAN_HARDWARE_Err = 7           'CAN Hardware Init Fail
Global Const CAN_PortNo_Err = 8             'The Device doesn't support this CAN Port
Global Const CAN_FIDLength_Err = 9          'The CAN Filter-ID Number exceed Max Number
Global Const CAN_DevDisconnect_Err = 10     'The Connection of device is broken
Global Const CAN_TimeOut_Err = 11           'The Config Command Timeout
Global Const CAN_ConfigCmd_Err = 12         'The Config Command doesn't support
Global Const CAN_ConfigBusy_Err = 13        'The Config Command is busy
Global Const CAN_RxBufEmpty = 14            'The CAN Receive Buffer is empty
Global Const CAN_TxBufFull = 15             'The CAN Send Buffer is full
Global Const CAN_UserDefISRNo_Err = 16      'The User Defined ISR No Error (0~7)
Global Const CAN_HWSendTimerNo_Err = 17     'The Hardware SendTimer No. Error (0~4)

'--------------------------------------------------
' Common Variable and Array
'--------------------------------------------------
Global Const CAN1 = 1
Global Const CAN2 = 2
Global Const CONFIG_MODE = 0
Global Const COMM_MODE = 1
Public ErrMessage
Public CANBaud_Arr

'--------------------------------------------------
' Device Type
'--------------------------------------------------
Global Const I7565H1 = 1
Global Const I7565H2 = 2

'--------------------------------------------------
' CANMsg Define
'--------------------------------------------------
Global Const MODE_11BIT = 0
Global Const MODE_29BIT = 1
Global Const RTR_0 = 0
Global Const RTR_1 = 1
Global Const DLC_0 = 0
Global Const DLC_1 = 1
Global Const DLC_2 = 2
Global Const DLC_3 = 3
Global Const DLC_4 = 4
Global Const DLC_5 = 5
Global Const DLC_6 = 6
Global Const DLC_7 = 7
Global Const DLC_8 = 8

'--------------------------------------------------
' ADDMODE Define
'--------------------------------------------------
Global Const ADDITION_MODE = 1
Global Const MULTIPLE_MODE = 2

'--------------------------------------------------
' UserDefISR Define
'--------------------------------------------------
Global Const ISRNO_0 = 0
Global Const ISRNO_1 = 1
Global Const ISRNO_2 = 2
Global Const ISRNO_3 = 3
Global Const ISRNO_4 = 4
Global Const ISRNO_5 = 5
Global Const ISRNO_6 = 6
Global Const ISRNO_7 = 7
Global Const ISR_CANPORT_ALL = 0
Global Const ISR_CANMODE_ALL = 2
Global Const ISR_CANID_ALL = 0

'--------------------------------------------------
' CAN Baudrate
'--------------------------------------------------
Global Const CANBaud_5K = 5000
Global Const CANBaud_10K = 10000
Global Const CANBaud_20K = 20000
Global Const CANBaud_40K = 40000
Global Const CANBaud_50K = 50000
Global Const CANBaud_80K = 80000
Global Const CANBaud_100K = 100000
Global Const CANBaud_125K = 125000
Global Const CANBaud_200K = 200000
Global Const CANBaud_250K = 250000
Global Const CANBaud_400K = 400000
Global Const CANBaud_500K = 500000
Global Const CANBaud_600K = 600000
Global Const CANBaud_800K = 800000
Global Const CANBaud_1000K = 1000000



'--------------------------------------------------
' ICPDAS VCICAN Series Message Structure Format
'--------------------------------------------------
'[1]. VCICAN - Module Info Format
Public Type VCI_MODULE_INFO
    Mod_ID(11) As Byte
    FW_Ver(11) As Byte
    HW_SN(15) As Byte
End Type

'[2]. VCICAN - CAN Parameter (CANBaud: Unit(bps))
Public Type VCI_CAN_PARAM
    DevPort As Byte
    DevType As Byte
    CAN1_Baud As Long
    CAN2_Baud As Long
End Type

Public Type VCI_CAN_PARAM_EX
    DevPort As Byte
    DevType As Byte
    CAN1_Baud As Long
    CAN2_Baud As Long
    CAN1_T2Val As Byte
    CAN2_T2Val As Byte
    Reserved(32) As Byte
End Type

'[3]. VCICAN - CAN Message Format
Public Type VCI_CAN_MSG
    Mode As Byte
    RTR As Byte
    DLC As Byte
    Reserved As Byte
    ID As Long
    TimeL As Long
    TimeH As Long
    Data(7) As Byte
End Type

'[4]. VCICAN - CAN FilterID Format
Public Type VCI_CAN_FilterID
    SSFF_Num As Integer
    GSFF_Num As Integer
    SEFF_Num As Integer
    GEFF_Num As Integer
    SSFF_FID(511) As Integer
    GSFF_FID(511) As Long
    SEFF_FID(511) As Long
    GEFF_FID(511) As Long
End Type

'[5]. VCICAN - CAN Status Format
Public Type VCI_CAN_STATUS
    CurCANBaud As Long
    CANReg As Byte
    CANTxErrCnt As Byte
    CANRxErrCnt As Byte
    MODState As Byte
    Reserved As Long
End Type



'--------------------------------------------------
'              VCI_CAN API Function
'--------------------------------------------------
'Public Declare Sub FillUDTVariable Lib "MyStDll.DLL" (A As My_VarUDT)
'[1] Init Function
Declare Function VCI_OpenCAN Lib "VCI_CAN.dll" (pCANPARAM As VCI_CAN_PARAM) As Integer
Declare Function VCI_CloseCAN Lib "VCI_CAN.dll" (ByVal DevPort As Byte) As Integer

'[2] Module Config Function
Declare Function VCI_Set_CANFID Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, pCANFID As VCI_CAN_FilterID) As Integer
Declare Function VCI_Get_CANFID Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, pCANFID As VCI_CAN_FilterID) As Integer
Declare Function VCI_Get_CANStatus Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, pCANStatus As VCI_CAN_STATUS) As Integer
Declare Function VCI_Clr_BufOverflowLED Lib "VCI_CAN.dll" (ByVal CAN_No As Byte) As Integer
Declare Function VCI_Get_MODInfo Lib "VCI_CAN.dll" (pMODInfo As VCI_MODULE_INFO) As Integer
Declare Function VCI_Rst_MOD Lib "VCI_CAN.dll" () As Integer
Declare Function VCI_Set_MOD_Ex Lib "VCI_CAN.dll" (ByRef CfgData As Byte) As Integer

'[3] Communication Function
Declare Function VCI_SendCANMsg Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, pCANMsg As VCI_CAN_MSG) As Integer
Declare Function VCI_RecvCANMsg Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, pCANMsg As VCI_CAN_MSG) As Integer
Declare Function VCI_EnableHWCyclicTxMsg Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, pCANMsg As VCI_CAN_MSG, ByVal TimePeriod As Long, ByVal TransmitTimes As Long) As Integer
Declare Function VCI_EnableHWCyclicTxMsg_NoStruct Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, ByVal Mode As Byte, ByVal RTR As Byte, ByVal DLC As Byte, ByVal ID As Long, ByRef Data As Byte, ByVal TimePeriod As Long, ByVal TransmitTimes As Long) As Integer
Declare Function VCI_DisableHWCyclicTxMsg Lib "VCI_CAN.dll" () As Integer
Declare Function VCI_EnableHWCyclicTxMsgNo Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, ByVal Mode As Byte, ByVal RTR As Byte, ByVal DLC As Byte, ByVal ID As Long, ByRef Data As Byte, ByVal TimePeriod As Long, ByVal TransmitTimes As Long, ByVal HW_TimerNo As Byte) As Integer
Declare Function VCI_EnableHWCyclicTxMsgNo_Ex Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, ByVal Mode As Byte, ByVal RTR As Byte, ByVal DLC As Byte, ByVal ID As Long, ByRef Data As Byte, ByVal TimePeriod As Long, ByVal TransmitTimes As Long, ByVal HW_TimerNo As Byte, ByVal AddMode As Byte, ByVal DLAddVal As Long, ByVal DHAddVal As Long) As Integer
Declare Function VCI_DisableHWCyclicTxMsgNo Lib "VCI_CAN.dll" (ByVal HW_TimerNo As Byte) As Integer

'[4] Software Buffer Function
Declare Function VCI_Get_RxMsgCnt Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, ByRef RxMsgCnt As Long) As Integer
Declare Function VCI_Get_RxMsgBufIsFull Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, ByRef Flag As Byte) As Integer
Declare Function VCI_Clr_RxMsgBuf Lib "VCI_CAN.dll" (ByVal CAN_No As Byte) As Integer
Declare Function VCI_Get_TxMsgCnt Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, ByRef TxMsgCnt As Long) As Integer
Declare Function VCI_Clr_TxMsgBuf Lib "VCI_CAN.dll" (ByVal CAN_No As Byte) As Integer
Declare Function VCI_Get_TxSentCnt Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, ByRef TxSentCnt As Long) As Integer
Declare Function VCI_Clr_TxSentCnt Lib "VCI_CAN.dll" (ByVal CAN_No As Byte) As Integer

'[5] UserDefine ISR Function
Declare Function VCI_Set_UserDefISR Lib "VCI_CAN.dll" (ByVal ISRNo As Byte, ByVal CAN_No As Byte, ByVal Mode As Byte, ByVal CANID As Long, ByVal UserDefISR As Long) As Integer
Declare Function VCI_Clr_UserDefISR Lib "VCI_CAN.dll" (ByVal ISRNo As Byte) As Integer
Declare Function VCI_Get_ISRCANData Lib "VCI_CAN.dll" (ByVal ISRNo As Byte, ByRef DLC As Byte, ByRef Data As Byte) As Integer
Declare Function VCI_Get_ISRCANData_Ex Lib "VCI_CAN.dll" (ByVal ISRNo As Byte, ByRef ID As Long, ByRef DLC As Byte, ByRef Data As Byte) As Integer

'[6] Other Function
Declare Function VCI_Get_DllVer Lib "VCI_CAN.dll" () As Long

'[7] Extended Function
Declare Function VCI_OpenCAN_Ex Lib "VCI_CAN.dll" (pCANPARAMEx As VCI_CAN_PARAM_EX) As Integer
Declare Function VCI_Get_CANBaud_BitTime Lib "VCI_CAN.dll" (ByVal CAN_No As Byte, ByRef T1Val As Byte, ByRef T2Val As Byte, ByRef SJWVal As Byte) As Integer



'--------------------------------------------------
'               General Function
'--------------------------------------------------
Public Sub Show_ErrCode(ByVal ErrCode As Byte)
    Err_String = "ErrCode= " & ErrCode & vbNewLine & _
                 "ErrMesg= " & ErrMessage(ErrCode)
End Sub

Public Function Bit_RMove(ByVal Data As Long, ByVal mBitNum As Long, ByVal tBitNum As Long) As Long
    Bit_RMove = (Data \ (2 ^ mBitNum)) And (2 ^ tBitNum - 1)
    
End Function

Public Function TPFLOATMS(ByVal fVal As Single)
    TPFLOATMS = CLng(fVal * 10) + 100000000
    
End Function


Public Sub I7565H1H2_Init()
    ErrMessage = Array( _
                     "No_Err", "DEV_ModName_Err", "DEV_ModNotExist_Err", _
                     "DEV_PortNotExist_Err", "DEV_PortInUse_Err", "DEV_PortNotOpen_Err", _
                     "CAN_ConfigFail_Err", "CAN_HARDWARE_Err", "CAN_PortNo_Err", _
                     "CAN_FIDLength_Err", "CAN_DevDisconnect_Err", "CAN_TimeOut_Err", _
                     "CAN_ConfigCmd_Err", "CAN_ConfigBusy_Err", "CAN_RxBufEmpty", _
                     "CAN_TxBufFull", "CAN_UserDefISRNo_Err" _
                )
    CANBaud_Arr = Array( _
                    CANBaud_5K, CANBaud_10K, CANBaud_20K, CANBaud_40K, _
                    CANBaud_50K, CANBaud_80K, CANBaud_100K, CANBaud_125K, _
                    CANBaud_200K, CANBaud_250K, CANBaud_400K, CANBaud_500K, _
                    CANBaud_600K, CANBaud_800K, CANBaud_1000K _
                )
                
End Sub
